/*****************************************************************************
 *                                18fUtil.h                                  *
 *****************************************************************************
 
Utility functions, types, and definitions for the StickBot Controller using
the PIC18Fxxx

*****************************************************************************/

#ifndef __18FUTIL_H
#define __18FUTIL_H


/*****************************************************************************
					PUBLIC TYPES, MACROS, DEFINITIONS
*****************************************************************************/

/* This is the list of all error codes for the sticky bot controller.  If we
 * keeps these unique across all modules and functions, they can be passed to
 * the error display function to indicate unambiguously to the user what error
 * (if any) occured. */

#define		SUCCESS					0
#define		UNHANDLED_KEY			1
#define		FLASH_DATA_ACCESS		2
#define		FLASH_DATA_OVERRUN		3
#define		NO_STANCE_CNTRL_DATA	4


/* Bit definitions */
#define BIT0		0b00000001
#define BIT1		0b00000010
#define BIT2		0b00000100
#define BIT3		0b00001000
#define BIT4		0b00010000
#define BIT5		0b00100000
#define BIT6		0b01000000
#define BIT7		0b10000000


/* Representation of a byte which gives access directly to the bits */
typedef union {
	struct {
		unsigned bit0:1;
		unsigned bit1:1;
		unsigned bit2:1;
		unsigned bit3:1;
		unsigned bit4:1;
		unsigned bit5:1;
		unsigned bit6:1;
		unsigned bit7:1;
	};
	unsigned char byte;
} Byte_t;

/* Macros for delays */
#define Milliseconds(t1)	Delay10KTCYx(t1)
#define Microseconds(t2)	Delay10TCYx(t2)

/* System clock speed (for use with timers and USART) */
#define FOSC		40000	//KHz

/* Program Flash Memory Locations (need to match the linker script) */
#define FLASH_PROG			0x0000
#define FLASH_PROG_END		0x5FFF
#define FLASH_DATA			0x6000
#define FLASH_DATA_END		0x7FFF
#define FLASH_END			0x7FFF

#define FLASH_DATA_BYTES	(FLASH_END - FLASH_DATA + 1)

/*****************************************************************************
						PUBLIC FUNCTION PROTOTYPES
*****************************************************************************/

#endif //__18FUTIL_H
