/*****************************************************************************
 *                                 Display.c                                 *
 *****************************************************************************

Display routines for the StickyBot controller board.

Date:		Author:				Comment:
------------------------------------------------------------------------------
2006-6-30	Barrett Heyneman	Original version, abstracting out all display
									control (LEDs) and adding error display
									functionality.

*****************************************************************************/

#include "Display.h"
#include "Keys.h"
#include <delays.h>
#include <p18cxxx.h>


/*****************************************************************************
					PRIVATE TYPES, MACROS, DEFINITIONS
*****************************************************************************/
#define LED_TRIS			TRISC
#define LED_TRIS_VAL		0b11111100 //PORTC<1:0> outputs


/*****************************************************************************
							PRIVATE VARIABLES
*****************************************************************************/


/*****************************************************************************
						PRIVATE FUNCTION PROTOTYPES
*****************************************************************************/


/*****************************************************************************
						PUBLIC FUNCTION DEFINITIONS
*****************************************************************************/

/****************************** InitDisplay **********************************

Initializes the pins for the two LED's to outputs and makes sure that they are
both turned off.

Last Modified:
Barrett Heyneman 	2006-6-30

*****************************************************************************/

void DSP_InitDisplay(void)
{
	/* Make the LED pins outputs */
	LED_TRIS &= LED_TRIS_VAL;
	
	/* Turn both LED's off */
	DSP_SetGreen(0);
	DSP_SetRed(0);
	
	return;
}


/********************************* Hello *************************************

Hello flashes the green LED, then the red, then the green again to indicate
that all modules were initialized correctly.

Last Modified:
Barrett Heyneman	2006-6-30

*****************************************************************************/

void DSP_Hello(void)
{
	/* Turn on the green LED */
	DSP_SetGreen(1);
	
	/* Wait for a total of 500ms */
	Delay10KTCYx(250);
	Delay10KTCYx(250);
	
	/* Turn the green off and the red on */
	DSP_SetGreen(0);
	DSP_SetRed(1);
	
	/* Wait for a total of 500ms */
	Delay10KTCYx(250);
	Delay10KTCYx(250);
	
	/* Turn the red off and the green on */
	DSP_SetRed(0);
	DSP_SetGreen(1);
	
	/* Wait for a total of 500ms */
	Delay10KTCYx(250);
	Delay10KTCYx(250);
	
	/* Turn off the green LED */
	DSP_SetGreen(0);
	
	return;
}


/*********************************** Error ***********************************

Flashes the red LED a number of times corresponding to the error code sent as
the argument (consult Display.h for the error codes).  This display will be
repeated (and this code will block) until the start button is pressed on the
controller.  While repeating, interrupts will be disabled.

Last Modified:
Barrett Heyneman	2006-6-30

*****************************************************************************/

void DSP_ShowError(unsigned char err)
{	
	/* Keep looping until the start key is pressed */
	while (!CheckSingleKey(KEY_0))
	{		
		/* Flash the correct number of times */
		while(err--)
		{
			/* Turn on the red LED for 250ms */
			DSP_SetRed(1);
			Milliseconds(125);
			
			/* Turn off the red LED for 250ms */
			DSP_SetRed(0);
			Milliseconds(125);
		}
		
		/* Wait for half a second before repeating */
		Milliseconds(250);
		Milliseconds(250);
	}
	
	return;
}
