#include "FileReader.h"
#include "18f4520_flash.h"
#include "ServoConfig.h"

#define START_OFFSET 2

//RAM memory of TOC values
static int LocOfLimits = NULL_MEM_PTR;
static unsigned char TOC_Entries;

//Working variables
static unsigned char i;

unsigned int FR_FindEntry(unsigned char EntryType)
{
	uint16 ret_val;
	//Check the size of the TOC
	TOC_Entries = ReadFlashByte(FLASH_DATA + START_OFFSET);
	for(i = 0; i < TOC_Entries; i++)
	{ 
		//Find the index of the first entry
		if (ReadFlashByte(FLASH_DATA + START_OFFSET + (3 * i) + 1) == EntryType)
		{
			//Little-endian
			ret_val.LowerByte = ReadFlashByte(FLASH_DATA + START_OFFSET + (3*i) + 2);
			ret_val.UpperByte = ReadFlashByte(FLASH_DATA + START_OFFSET + (3*i) + 3);
			ret_val.AsInt += FLASH_DATA;
			return( ret_val.AsInt );
		}
	}
	return (NULL_MEM_PTR);
}

void FR_GetServoConfig(unsigned char * HomeArray_out,
					   unsigned char * LowerArray_out,
					   unsigned char * UpperArray_out)
{
	static unsigned char MaxServoEntries = 0;

	//Fetch the location of the limits in FLASH
	if (LocOfLimits == NULL_MEM_PTR)
		LocOfLimits = FR_FindEntry(SERVO_CONFIG_TABLE);

	if (LocOfLimits == NULL_MEM_PTR)
		//They don't exist in memory. Don't overwrite the current values
		return;

	//Get the max number of entries
	MaxServoEntries = ReadFlashByte(LocOfLimits);

	if (MaxServoEntries != NUM_OF_SERV)
	{
		//Send a message to the host informing a mismatch, but still load the values

		//WORK HERE
	}

	for (i = 0; ((i < MaxServoEntries) && (i < NUM_OF_SERV)); i++)
	{
		//Read each entry
		HomeArray_out[i] =  ReadFlashByte(LocOfLimits + (3 * i) + 1);
		LowerArray_out[i] = ReadFlashByte(LocOfLimits + (3 * i) + 2);
		UpperArray_out[i] = ReadFlashByte(LocOfLimits + (3 * i) + 3);
	}
}

void FR_ReadGestureData(unsigned int * byte_inx, unsigned char * cmd, unsigned int * data)
{
	*cmd = ReadFlashByte((*byte_inx)++);

	switch ((*cmd) & 0xF0)
	{
		case 0x90:
			//Don't read any bytes
		break;
		case 0x80:
			//Read in a 8-bit number
			*data = ReadFlashByte((*byte_inx)++);
		break;
		default:
			//Read in a 16-bit number
			*data = ReadFlashByte((*byte_inx)++);
			*((unsigned char *)data + 1) =
				ReadFlashByte((*byte_inx)++);
		break;
	}
}
