/*****************************************************************************
*                               MatrixMath.h                                 *
******************************************************************************

Partially speed optimized N dimensional Matrix Math library.  All numbers are
signed integers, with decimal point between the bytes (base 1/256).  

Date:		Author:				Comments:
------------------------------------------------------------------------------
2006-8-2	Barrett Heyneman	Original version; issues with data overflow
								(because not using floating point) which may
								need to be addressed by restricting controller
								parameters to two byte (signed int) but promoting
								during calculations to signed (short?) longs.
								
*****************************************************************************/

#ifndef __MATRIX_MATH_H
#define __MATRIX_MATH_H

#include "ControllerMath.h"


/*****************************************************************************
						PUBLIC TYPES, DEFINTIONS, MACROS
*****************************************************************************/

/* Dimension for the matrix math to work in; NxN matrices and Nx1 vectors */
#define MATRIX_DIM		4


/*****************************************************************************
							PUBLIC FUNCTION PROTOTYPES
*****************************************************************************/

/* NxN Matrix, NxN Matrix multiplication.  If 'M' overlaps 'mat1' or 'mat2'
 * in memory, operation is undefined. */
void MatrixMatrix(Number_t mat1[MATRIX_DIM][MATRIX_DIM],
                  Number_t mat2[MATRIX_DIM][MATRIX_DIM],
                  Number_t M[MATRIX_DIM][MATRIX_DIM]);

/* NxN Matrix, Nx1 Vector multiplication.  If 'V' overlaps 'mat' or 'vec'
 * in memory, operation is undefined. */
void MatrixVector(Number_t mat[MATRIX_DIM][MATRIX_DIM],
                  Number_t vec[MATRIX_DIM], Number_t V[MATRIX_DIM]);

/* Nx1 Vector Dot Product */
Number_t VectorDot(Number_t vec1[MATRIX_DIM], Number_t vec2[MATRIX_DIM]);

/* Nx1 Vector Addition */
void VectorAdd(Number_t vec1[MATRIX_DIM], Number_t vec2[MATRIX_DIM],
               Number_t V[MATRIX_DIM]);

/* Nx1 Vector Subtraction */
void VectorSub(Number_t vec1[MATRIX_DIM], Number_t vec2[MATRIX_DIM],
               Number_t V[MATRIX_DIM]);

/* Nx1 Vector Elementwise Multiplication */
void VectorMul(Number_t vec1[MATRIX_DIM], Number_t vec2[MATRIX_DIM],
               Number_t V[MATRIX_DIM]);


#endif  /*__MATRIX_MATH_H */
