/*****************************************************************************
*                           StanceController.h                               *
******************************************************************************

Implements a control scheme for legs within stance.  The controller assumes
that all legs are in stance and returns delta position commands for all the
servos.  It is up to any higher level controller to determine whether those
deltas are actually applied or not.

*****************************************************************************/

#ifndef __STANCE_CONTROLLER_H
#define __STANCE_CONTROLLER_H

#include "PhysicalConfig.h"

/*****************************************************************************
						PUBLIC TYPES, DEFINITIONS, MACROS
*****************************************************************************/


/*****************************************************************************
							PUBLIC FUNCTION PROTOTYPES
*****************************************************************************/

/* Initializes the Stance Controller by loading the correct gains, grasp
 * matrices, etc, from flash */
void InitStanceControl(void);

/* Loads the ExactPositions_t object pointed to by deltas with the computed
 * command deltas for all the servos */
void StanceControl(ServoGroupNumber_t *deltas);


void SetForceDesired(SensorGroupNumber_t *force_desired);
void GetForceDesired(SensorGroupNumber_t *force_desired);

#endif	//__STANCE_CONTROLLER_H
