#include "18fUtil.h"

#pragma romdata FlashData = FLASH_DATA
const rom unsigned int SizeOfFlashFile = 0x00EF;

//# of entries
const rom unsigned char NumOfEntries =	0x06;
//Servo Table at 0x000A
const rom unsigned char ServoTableEntry = 0x30;
const rom unsigned int ServoTableAddress = 0x0015; 
//Sensor Table at 0x002F
const rom unsigned char SensorTableEntry = 0x31;
const rom unsigned int SensorTableAddress = 0x003A; 
//Stance Control Data at 0x003C
const rom unsigned char StanceControlEntry = 0x32;
const rom unsigned int StanceControlAddress = 0x0047; 
//Gesture Data at 0x0099;
const rom unsigned char AttachGestureEntry = 0x36;
const rom unsigned int AttachGestureAddress = 0x009F; 
//
const rom unsigned char DetachGestureEntry = 0x37;
const rom unsigned int DetachGestureAddress = 0x00C8; 
	
const rom unsigned char ShiftWeightGestureEntry = 0x40;
const rom unsigned int ShiftWeightGestureAddress = 0x00E1; 

/* Servo Table */
const rom unsigned char ServoConfig[] = {	
	0x0C, //12 servos
 
	0x44, 0xCB, 0x52, 0xBC, 0x6E, 0x91, 0x88, 0x8E, 0x81, 0x67, 0x8B, 0x84,
//    68,  203,  82, 188, 119, 144, 166, 116, 145, 103, 139, 152,  //Home
   195,  221, 209, 217, 208, 222, 215, 242, 255, 151, 174, 255, //Upper
    31,  76,   51,  61,  48,  66,  39,  62, 103,   0,  12, 100  //Lower
};

/* Sensor Table */
const rom unsigned char SensorTable[] = {
	0x04, //4 sensors
	120, 120, 120, 120, //Zeros
	0x33, 0x00, 0x33, 0x00, 0x33, 0x00, 0x33, 0x00 //Slopes
};

/* Stance controller */
const rom unsigned char StanceController[] = {
	//G
	0x80, 0x00, 0x80, 0x00, 0x80, 0x00, 0x80, 0x00,
	0x80, 0x00, 0x80, 0xFF, 0x80, 0x00, 0x80, 0xFF,
	0x80, 0x00, 0x80, 0x00, 0x80, 0xFF, 0x80, 0xFF,
	0x80, 0x00, 0x80, 0xFF, 0x80, 0xFF, 0x80, 0x00,
	//inv(G)
	0x80, 0x00, 0x80, 0x00, 0x80, 0x00, 0x80, 0x00,
	0x80, 0x00, 0x80, 0xFF, 0x80, 0x00, 0x80, 0xFF,
	0x80, 0x00, 0x80, 0x00, 0x80, 0xFF, 0x80, 0xFF,
	0x80, 0x00, 0x80, 0xFF, 0x80, 0xFF, 0x80, 0x00,
	//Kg
	0x00, 0x0F, 0x00, 0x0F, 0x00, 0x0F, 0x00, 0x0F,
	//Fd
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	//Vff
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
};

const rom unsigned char AttachGesture[] = {
	//Make contact with wall
	0x22, 0x00, 0xFA,
	0x80, 0x0A,

	//Press in and down for preload
	0x22, 0x66, 0xF6,
	0x21, 0x6A, 0xFF,
	0x80, 0x05,

	//Uncurl foot
	0x22, 0x00, 0x00,
	0x20, 0xE8, 0xFF,
	0x80, 0x05,
	0x10, 0x00, 0x00,

	//Hold
	0x20, 0x00, 0x00,
	0x80, 0x02,

	//Release 
	0x22, 0xCD, 0x04,
	0x80, 0x0A,

	//Done
	0x22, 0x00, 0x00,
	0x21, 0x00, 0x00,
	0x90
};

const rom unsigned char DetachGesture[] = {
	//Curl foot
	0x20, 0x00, 0x28,
	0x80, 0x03,

	//Hold
	0x20, 0x00, 0x00,
	0x80, 0x02,

	//Lift from wall
	0x22, 0x00, 0x06,
	0x21, 0x90, 0x01,
	0x80, 0x0A,

	//Done
	0x21, 0x00, 0x00,
	0x22, 0x00, 0x00,
	0x90,
};

/*
	DecreasingStiffnessGesture
	0x11, 0x00, 0x00,
	0x61, 0xB0, 0xFF,
	0x71, 0x01, 0x00,
	0x80, 0x70,
	0x80, 0x70,
	0x80, 0x70,
	0x71, 0x00, 0x00,
	0x90
*/

const rom unsigned char ShiftWeightGesture[] = {
	0x21, 0xF4, 0xFF,
	0x80, 0x7F,
	0x80, 0x7F,
	0x21, 0x0C, 0x00,
	0x80, 0x7F,
	0x80, 0x7F,
	0x21, 0x00, 0x00,
	0x80, 0x7F,
	0x80, 0x7F,
	0x90
};

const rom unsigned char EndByte = 0xFF;

#pragma code
