#include <p18cxxx.h>
#include "servo.h"
#include "serial.h"

/* These registers are used by the delay functions. */
extern unsigned char DelayCounter1;
extern unsigned char DelayCounter2;

//Private variable for timer event
unsigned char TimerEventFlag = 0;

/* Private variables to save the counts for delays */
static unsigned char DelayTemp1;
static unsigned char DelayTemp2;

//Private function prototypes
void highISR(void);
static void TimerUpdate(void);

////////////////////////////////
// HIGH INTERRUPT SERVICE ROUTINE
////////////////////////////////

// Code Vectoring
#pragma code high_vector=0x08
void interrupt_at_high_vector(void)
{
_asm GOTO highISR _endasm
}
#pragma code /* return to the default code section */

// High ISR Code
#pragma interruptlow highISR
void highISR( void )
{
	/* Save the counter values; need to because the servo PWM generation uses
	 * the delay counters and may overwrite counter values if we interrupt
	 * during a call to one of the delay functions.
	 */
	DelayTemp1 = DelayCounter1;
	DelayTemp2 = DelayCounter2;
	
	if (PIR2bits.CCP2IF)
		TimerUpdate();

	//Flag checking and clearing is done automatically in this function
	SRL_HandleSerialPort();	
	
	/* Restore the original delay counts */
	DelayCounter1 = DelayTemp1;
	DelayCounter2 = DelayTemp2;
}

////////////////////////////////
// LOW INTERRUPT SERVICE ROUTINE
////////////////////////////////

// Code Vectoring
#pragma code low_vector=0x18
void interrupt_at_low_vector(void)
{
_asm GOTO highISR _endasm
}
#pragma code /* return to the default code section */

static void TimerUpdate( void )	// must be less than 20ms (including interrupt overhead)
{
	PIR2bits.CCP2IF = 0;	// Clear compare interrupt flag
	SRV_GenerateServoPWM();		// Generate the servo PWM signal.
	TimerEventFlag = 1;		// Set timer flag
}

unsigned char HasTimerTriggered(void)
{
	//Check flag, but clear it after reading it.
	if (TimerEventFlag)
	{
		TimerEventFlag = 0;
		return(1);
	}	
	return(0);
}
